==> deduck-1.0.1-py3-none-any.whl: duck/__main__.py <==
# -*- coding: utf-8 -*-

"""
The MIT License (MIT)

Copyright (c) 2022-present Artic

Permission is hereby granted, free of charge, to any person obtaining a
copy of this software and associated documentation files (the "Software"),
to deal in the Software without restriction, including without limitation
the rights to use, copy, modify, merge, publish, distribute, sublicense,
and/or sell copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
DEALINGS IN THE SOFTWARE.
"""

duck: str = """                                                                                                            
                    __builtins__
                str("Hello, World!")
               [1, 2, 3, 4].append(5)
               __keys__: str = "name"
        from os import getcwd as path
       def main(integ: int) -> None:
        if integ is not type(int):
          raise SyntaxError("")
               print("Hello")
              eval("1 + 1")                 import sys
             for i in l:            with open(sys.argv[1]) as f:
            print(l[:i])       __content__: object = f.readlines()
           __locals__: dict[str: object()] = {}; eval("5**5 + 5 / 9")
           r = exec("data = input('How's your day ?')", {}, __locals__)
           answer = "yay" if __locals__["data"] == "good" else "why ??"
           yield "Artic!" if "github" in "https://github.com/ArticOff"
            print(answer); exec(compile("globals()['__name__']")); r
             L = [for i in range(10) if i not in [1, 3, 5, 7, 9]]
              main(7) if __name__ == "__main__" else print("no")
                import this; assert name == "Artic#3065"; 141
                   sys.exit(0) if isinstance(32767, int); L
            
            Hi! explain your problem to me... quack! quack!
"""

print(duck)

==> deduck-1.0.2-py3-none-any.whl: duck/__main__.py <==
# -*- coding: utf-8 -*-

"""
The MIT License (MIT)

Copyright (c) 2022-present Artic

Permission is hereby granted, free of charge, to any person obtaining a
copy of this software and associated documentation files (the "Software"),
to deal in the Software without restriction, including without limitation
the rights to use, copy, modify, merge, publish, distribute, sublicense,
and/or sell copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
DEALINGS IN THE SOFTWARE.
"""

duck: str = """                                                                                                            
                    __builtins__
                str("Hello, World!")
               [1, 2, 3, 4].append(5)
               __keys__: str = "name"
        from os import getcwd as path
       def main(integ: int) -> None:
        if integ is not type(int):
          raise SyntaxError("")
               print("Hello")
              eval("1 + 1")                 import sys
             for i in l:            with open(sys.argv[1]) as f:
            print(l[:i])       __content__: object = f.readlines()
           __locals__: dict[str: object()] = {}; eval("5**5 + 5 / 9")
           r = exec("data = input('Hows your day ?')", {}, __locals__)
           answer = "yay" if __locals__["data"] == "good" else "why ??"
           yield "Artic!" if "github" in "https://github.com/ArticOff"
            print(answer); exec(compile("globals()['__name__']")); r
             L = [for i in range(10) if i not in [1, 3, 5, 7, 9]]
              main(7) if __name__ == "__main__" else print("no")
                import this; assert name == "Artic#3065"; 141
                   sys.exit(0) if isinstance(32767, int); L
            
            Hi! explain your problem to me... quack! quack!
"""

print(duck)
